
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tendermint.crypto import proof_pb2 as _proof_pb2
from tendermint.version import types_pb2 as _types_pb2
from tendermint.types import validator_pb2 as _validator_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
BLOCK_ID_FLAG_ABSENT: BlockIDFlag
BLOCK_ID_FLAG_COMMIT: BlockIDFlag
BLOCK_ID_FLAG_NIL: BlockIDFlag
BLOCK_ID_FLAG_UNKNOWN: BlockIDFlag
DESCRIPTOR: _descriptor.FileDescriptor
SIGNED_MSG_TYPE_PRECOMMIT: SignedMsgType
SIGNED_MSG_TYPE_PREVOTE: SignedMsgType
SIGNED_MSG_TYPE_PROPOSAL: SignedMsgType
SIGNED_MSG_TYPE_UNKNOWN: SignedMsgType

class BlockID(_message.Message):
    __slots__ = ['hash', 'part_set_header']
    HASH_FIELD_NUMBER: _ClassVar[int]
    PART_SET_HEADER_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    part_set_header: PartSetHeader

    def __init__(self, hash: _Optional[bytes]=..., part_set_header: _Optional[_Union[(PartSetHeader, _Mapping)]]=...) -> None:
        ...

class BlockMeta(_message.Message):
    __slots__ = ['block_id', 'block_size', 'header', 'num_txs']
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    BLOCK_SIZE_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NUM_TXS_FIELD_NUMBER: _ClassVar[int]
    block_id: BlockID
    block_size: int
    header: Header
    num_txs: int

    def __init__(self, block_id: _Optional[_Union[(BlockID, _Mapping)]]=..., block_size: _Optional[int]=..., header: _Optional[_Union[(Header, _Mapping)]]=..., num_txs: _Optional[int]=...) -> None:
        ...

class Commit(_message.Message):
    __slots__ = ['block_id', 'height', 'round', 'signatures']
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    block_id: BlockID
    height: int
    round: int
    signatures: _containers.RepeatedCompositeFieldContainer[CommitSig]

    def __init__(self, height: _Optional[int]=..., round: _Optional[int]=..., block_id: _Optional[_Union[(BlockID, _Mapping)]]=..., signatures: _Optional[_Iterable[_Union[(CommitSig, _Mapping)]]]=...) -> None:
        ...

class CommitSig(_message.Message):
    __slots__ = ['block_id_flag', 'signature', 'timestamp', 'validator_address']
    BLOCK_ID_FLAG_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    block_id_flag: BlockIDFlag
    signature: bytes
    timestamp: _timestamp_pb2.Timestamp
    validator_address: bytes

    def __init__(self, block_id_flag: _Optional[_Union[(BlockIDFlag, str)]]=..., validator_address: _Optional[bytes]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., signature: _Optional[bytes]=...) -> None:
        ...

class Data(_message.Message):
    __slots__ = ['txs']
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]

    def __init__(self, txs: _Optional[_Iterable[bytes]]=...) -> None:
        ...

class Header(_message.Message):
    __slots__ = ['app_hash', 'chain_id', 'consensus_hash', 'data_hash', 'evidence_hash', 'height', 'last_block_id', 'last_commit_hash', 'last_results_hash', 'next_validators_hash', 'proposer_address', 'time', 'validators_hash', 'version']
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_HASH_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_HASH_FIELD_NUMBER: _ClassVar[int]
    LAST_RESULTS_HASH_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    app_hash: bytes
    chain_id: str
    consensus_hash: bytes
    data_hash: bytes
    evidence_hash: bytes
    height: int
    last_block_id: BlockID
    last_commit_hash: bytes
    last_results_hash: bytes
    next_validators_hash: bytes
    proposer_address: bytes
    time: _timestamp_pb2.Timestamp
    validators_hash: bytes
    version: _types_pb2.Consensus

    def __init__(self, version: _Optional[_Union[(_types_pb2.Consensus, _Mapping)]]=..., chain_id: _Optional[str]=..., height: _Optional[int]=..., time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., last_block_id: _Optional[_Union[(BlockID, _Mapping)]]=..., last_commit_hash: _Optional[bytes]=..., data_hash: _Optional[bytes]=..., validators_hash: _Optional[bytes]=..., next_validators_hash: _Optional[bytes]=..., consensus_hash: _Optional[bytes]=..., app_hash: _Optional[bytes]=..., last_results_hash: _Optional[bytes]=..., evidence_hash: _Optional[bytes]=..., proposer_address: _Optional[bytes]=...) -> None:
        ...

class LightBlock(_message.Message):
    __slots__ = ['signed_header', 'validator_set']
    SIGNED_HEADER_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SET_FIELD_NUMBER: _ClassVar[int]
    signed_header: SignedHeader
    validator_set: _validator_pb2.ValidatorSet

    def __init__(self, signed_header: _Optional[_Union[(SignedHeader, _Mapping)]]=..., validator_set: _Optional[_Union[(_validator_pb2.ValidatorSet, _Mapping)]]=...) -> None:
        ...

class Part(_message.Message):
    __slots__ = ['bytes', 'index', 'proof']
    BYTES_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    bytes: bytes
    index: int
    proof: _proof_pb2.Proof

    def __init__(self, index: _Optional[int]=..., bytes: _Optional[bytes]=..., proof: _Optional[_Union[(_proof_pb2.Proof, _Mapping)]]=...) -> None:
        ...

class PartSetHeader(_message.Message):
    __slots__ = ['hash', 'total']
    HASH_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    total: int

    def __init__(self, total: _Optional[int]=..., hash: _Optional[bytes]=...) -> None:
        ...

class Proposal(_message.Message):
    __slots__ = ['block_id', 'height', 'pol_round', 'round', 'signature', 'timestamp', 'type']
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    POL_ROUND_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    block_id: BlockID
    height: int
    pol_round: int
    round: int
    signature: bytes
    timestamp: _timestamp_pb2.Timestamp
    type: SignedMsgType

    def __init__(self, type: _Optional[_Union[(SignedMsgType, str)]]=..., height: _Optional[int]=..., round: _Optional[int]=..., pol_round: _Optional[int]=..., block_id: _Optional[_Union[(BlockID, _Mapping)]]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., signature: _Optional[bytes]=...) -> None:
        ...

class SignedHeader(_message.Message):
    __slots__ = ['commit', 'header']
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    commit: Commit
    header: Header

    def __init__(self, header: _Optional[_Union[(Header, _Mapping)]]=..., commit: _Optional[_Union[(Commit, _Mapping)]]=...) -> None:
        ...

class TxProof(_message.Message):
    __slots__ = ['data', 'proof', 'root_hash']
    DATA_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    proof: _proof_pb2.Proof
    root_hash: bytes

    def __init__(self, root_hash: _Optional[bytes]=..., data: _Optional[bytes]=..., proof: _Optional[_Union[(_proof_pb2.Proof, _Mapping)]]=...) -> None:
        ...

class Vote(_message.Message):
    __slots__ = ['block_id', 'height', 'round', 'signature', 'timestamp', 'type', 'validator_address', 'validator_index']
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_INDEX_FIELD_NUMBER: _ClassVar[int]
    block_id: BlockID
    height: int
    round: int
    signature: bytes
    timestamp: _timestamp_pb2.Timestamp
    type: SignedMsgType
    validator_address: bytes
    validator_index: int

    def __init__(self, type: _Optional[_Union[(SignedMsgType, str)]]=..., height: _Optional[int]=..., round: _Optional[int]=..., block_id: _Optional[_Union[(BlockID, _Mapping)]]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., validator_address: _Optional[bytes]=..., validator_index: _Optional[int]=..., signature: _Optional[bytes]=...) -> None:
        ...

class BlockIDFlag(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class SignedMsgType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.session.v2 import params_pb2 as _params_pb2
from sentinel.session.v2 import session_pb2 as _session_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['params', 'sessions']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]

    def __init__(self, sessions: _Optional[_Iterable[_Union[(_session_pb2.Session, _Mapping)]]]=..., params: _Optional[_Union[(_params_pb2.Params, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from .....ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2
from .....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ibc/applications/transfer/v1/query.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a+ibc/applications/transfer/v1/transfer.proto\x1a\x1cgoogle/api/annotations.proto"&\n\x16QueryDenomTraceRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t"X\n\x17QueryDenomTraceResponse\x12=\n\x0bdenom_trace\x18\x01 \x01(\x0b2(.ibc.applications.transfer.v1.DenomTrace"U\n\x17QueryDenomTracesRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xa7\x01\n\x18QueryDenomTracesResponse\x12N\n\x0cdenom_traces\x18\x01 \x03(\x0b2(.ibc.applications.transfer.v1.DenomTraceB\x0e\xaa\xdf\x1f\x06Traces\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x14\n\x12QueryParamsRequest"K\n\x13QueryParamsResponse\x124\n\x06params\x18\x01 \x01(\x0b2$.ibc.applications.transfer.v1.Params"&\n\x15QueryDenomHashRequest\x12\r\n\x05trace\x18\x01 \x01(\t"&\n\x16QueryDenomHashResponse\x12\x0c\n\x04hash\x18\x01 \x01(\t2\xa4\x05\n\x05Query\x12\xac\x01\n\nDenomTrace\x124.ibc.applications.transfer.v1.QueryDenomTraceRequest\x1a5.ibc.applications.transfer.v1.QueryDenomTraceResponse"1\x82\xd3\xe4\x93\x02+\x12)/ibc/apps/transfer/v1/denom_traces/{hash}\x12\xa8\x01\n\x0bDenomTraces\x125.ibc.applications.transfer.v1.QueryDenomTracesRequest\x1a6.ibc.applications.transfer.v1.QueryDenomTracesResponse"*\x82\xd3\xe4\x93\x02$\x12"/ibc/apps/transfer/v1/denom_traces\x12\x93\x01\n\x06Params\x120.ibc.applications.transfer.v1.QueryParamsRequest\x1a1.ibc.applications.transfer.v1.QueryParamsResponse"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/ibc/apps/transfer/v1/params\x12\xaa\x01\n\tDenomHash\x123.ibc.applications.transfer.v1.QueryDenomHashRequest\x1a4.ibc.applications.transfer.v1.QueryDenomHashResponse"2\x82\xd3\xe4\x93\x02,\x12*/ibc/apps/transfer/v1/denom_hashes/{trace}B9Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/types'
    _QUERYDENOMTRACESRESPONSE.fields_by_name['denom_traces']._options = None
    _QUERYDENOMTRACESRESPONSE.fields_by_name['denom_traces']._serialized_options = b'\xaa\xdf\x1f\x06Traces\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['DenomTrace']._options = None
    _QUERY.methods_by_name['DenomTrace']._serialized_options = b'\x82\xd3\xe4\x93\x02+\x12)/ibc/apps/transfer/v1/denom_traces/{hash}'
    _QUERY.methods_by_name['DenomTraces']._options = None
    _QUERY.methods_by_name['DenomTraces']._serialized_options = b'\x82\xd3\xe4\x93\x02$\x12"/ibc/apps/transfer/v1/denom_traces'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1e\x12\x1c/ibc/apps/transfer/v1/params'
    _QUERY.methods_by_name['DenomHash']._options = None
    _QUERY.methods_by_name['DenomHash']._serialized_options = b'\x82\xd3\xe4\x93\x02,\x12*/ibc/apps/transfer/v1/denom_hashes/{trace}'
    _QUERYDENOMTRACEREQUEST._serialized_start = 215
    _QUERYDENOMTRACEREQUEST._serialized_end = 253
    _QUERYDENOMTRACERESPONSE._serialized_start = 255
    _QUERYDENOMTRACERESPONSE._serialized_end = 343
    _QUERYDENOMTRACESREQUEST._serialized_start = 345
    _QUERYDENOMTRACESREQUEST._serialized_end = 430
    _QUERYDENOMTRACESRESPONSE._serialized_start = 433
    _QUERYDENOMTRACESRESPONSE._serialized_end = 600
    _QUERYPARAMSREQUEST._serialized_start = 602
    _QUERYPARAMSREQUEST._serialized_end = 622
    _QUERYPARAMSRESPONSE._serialized_start = 624
    _QUERYPARAMSRESPONSE._serialized_end = 699
    _QUERYDENOMHASHREQUEST._serialized_start = 701
    _QUERYDENOMHASHREQUEST._serialized_end = 739
    _QUERYDENOMHASHRESPONSE._serialized_start = 741
    _QUERYDENOMHASHRESPONSE._serialized_end = 779
    _QUERY._serialized_start = 782
    _QUERY._serialized_end = 1458




from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Message(_message.Message):
    __slots__ = ['txs']
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: Txs

    def __init__(self, txs: _Optional[_Union[(Txs, _Mapping)]]=...) -> None:
        ...

class Txs(_message.Message):
    __slots__ = ['txs']
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]

    def __init__(self, txs: _Optional[_Iterable[bytes]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/interchain_security/ccv/consumer/v1/query.proto\x12#interchain_security.ccv.consumer.v1\x1a\x1cgoogle/api/annotations.proto"\xb2\x01\n\x1bNextFeeDistributionEstimate\x12\x15\n\rcurrentHeight\x18\x01 \x01(\x03\x12\x12\n\nlastHeight\x18\x02 \x01(\x03\x12\x12\n\nnextHeight\x18\x03 \x01(\x03\x12\x1d\n\x15distribution_fraction\x18\x04 \x01(\t\x12\r\n\x05total\x18\x05 \x01(\t\x12\x12\n\ntoProvider\x18\x06 \x01(\t\x12\x12\n\ntoConsumer\x18\x07 \x01(\t")\n\'QueryNextFeeDistributionEstimateRequest"z\n(QueryNextFeeDistributionEstimateResponse\x12N\n\x04data\x18\x01 \x01(\x0b2@.interchain_security.ccv.consumer.v1.NextFeeDistributionEstimate2\x82\x02\n\x05Query\x12\xf8\x01\n\x18QueryNextFeeDistribution\x12L.interchain_security.ccv.consumer.v1.QueryNextFeeDistributionEstimateRequest\x1aM.interchain_security.ccv.consumer.v1.QueryNextFeeDistributionEstimateResponse"?\x82\xd3\xe4\x93\x029\x127/interchain_security/ccv/consumer/next-fee-distributionB<Z:github.com/cosmos/interchain-security/x/ccv/consumer/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interchain_security.ccv.consumer.v1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z:github.com/cosmos/interchain-security/x/ccv/consumer/types'
    _QUERY.methods_by_name['QueryNextFeeDistribution']._options = None
    _QUERY.methods_by_name['QueryNextFeeDistribution']._serialized_options = b'\x82\xd3\xe4\x93\x029\x127/interchain_security/ccv/consumer/next-fee-distribution'
    _NEXTFEEDISTRIBUTIONESTIMATE._serialized_start = 119
    _NEXTFEEDISTRIBUTIONESTIMATE._serialized_end = 297
    _QUERYNEXTFEEDISTRIBUTIONESTIMATEREQUEST._serialized_start = 299
    _QUERYNEXTFEEDISTRIBUTIONESTIMATEREQUEST._serialized_end = 340
    _QUERYNEXTFEEDISTRIBUTIONESTIMATERESPONSE._serialized_start = 342
    _QUERYNEXTFEEDISTRIBUTIONESTIMATERESPONSE._serialized_end = 464
    _QUERY._serialized_start = 467
    _QUERY._serialized_end = 725




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ...tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from ...tendermint.libs.bits import types_pb2 as tendermint_dot_libs_dot_bits_dot_types__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/consensus/types.proto\x12\x14tendermint.consensus\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/libs/bits/types.proto"x\n\x0cNewRoundStep\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\r\x12 \n\x18seconds_since_start_time\x18\x04 \x01(\x03\x12\x19\n\x11last_commit_round\x18\x05 \x01(\x05"\xbc\x01\n\rNewValidBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12D\n\x15block_part_set_header\x18\x03 \x01(\x0b2\x1f.tendermint.types.PartSetHeaderB\x04\xc8\xde\x1f\x00\x123\n\x0bblock_parts\x18\x04 \x01(\x0b2\x1e.tendermint.libs.bits.BitArray\x12\x11\n\tis_commit\x18\x05 \x01(\x08">\n\x08Proposal\x122\n\x08proposal\x18\x01 \x01(\x0b2\x1a.tendermint.types.ProposalB\x04\xc8\xde\x1f\x00"u\n\x0bProposalPOL\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x1a\n\x12proposal_pol_round\x18\x02 \x01(\x05\x12:\n\x0cproposal_pol\x18\x03 \x01(\x0b2\x1e.tendermint.libs.bits.BitArrayB\x04\xc8\xde\x1f\x00"V\n\tBlockPart\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12*\n\x04part\x18\x03 \x01(\x0b2\x16.tendermint.types.PartB\x04\xc8\xde\x1f\x00",\n\x04Vote\x12$\n\x04vote\x18\x01 \x01(\x0b2\x16.tendermint.types.Vote"f\n\x07HasVote\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e2\x1f.tendermint.types.SignedMsgType\x12\r\n\x05index\x18\x04 \x01(\x05"\x9a\x01\n\x0cVoteSetMaj23\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e2\x1f.tendermint.types.SignedMsgType\x12<\n\x08block_id\x18\x04 \x01(\x0b2\x19.tendermint.types.BlockIDB\x0f\xe2\xde\x1f\x07BlockID\xc8\xde\x1f\x00"\xce\x01\n\x0bVoteSetBits\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e2\x1f.tendermint.types.SignedMsgType\x12<\n\x08block_id\x18\x04 \x01(\x0b2\x19.tendermint.types.BlockIDB\x0f\xe2\xde\x1f\x07BlockID\xc8\xde\x1f\x00\x123\n\x05votes\x18\x05 \x01(\x0b2\x1e.tendermint.libs.bits.BitArrayB\x04\xc8\xde\x1f\x00"\x8d\x04\n\x07Message\x12<\n\x0enew_round_step\x18\x01 \x01(\x0b2".tendermint.consensus.NewRoundStepH\x00\x12>\n\x0fnew_valid_block\x18\x02 \x01(\x0b2#.tendermint.consensus.NewValidBlockH\x00\x122\n\x08proposal\x18\x03 \x01(\x0b2\x1e.tendermint.consensus.ProposalH\x00\x129\n\x0cproposal_pol\x18\x04 \x01(\x0b2!.tendermint.consensus.ProposalPOLH\x00\x125\n\nblock_part\x18\x05 \x01(\x0b2\x1f.tendermint.consensus.BlockPartH\x00\x12*\n\x04vote\x18\x06 \x01(\x0b2\x1a.tendermint.consensus.VoteH\x00\x121\n\x08has_vote\x18\x07 \x01(\x0b2\x1d.tendermint.consensus.HasVoteH\x00\x12<\n\x0evote_set_maj23\x18\x08 \x01(\x0b2".tendermint.consensus.VoteSetMaj23H\x00\x12:\n\rvote_set_bits\x18\t \x01(\x0b2!.tendermint.consensus.VoteSetBitsH\x00B\x05\n\x03sumB=Z;github.com/tendermint/tendermint/proto/tendermint/consensusb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.consensus.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z;github.com/tendermint/tendermint/proto/tendermint/consensus'
    _NEWVALIDBLOCK.fields_by_name['block_part_set_header']._options = None
    _NEWVALIDBLOCK.fields_by_name['block_part_set_header']._serialized_options = b'\xc8\xde\x1f\x00'
    _PROPOSAL.fields_by_name['proposal']._options = None
    _PROPOSAL.fields_by_name['proposal']._serialized_options = b'\xc8\xde\x1f\x00'
    _PROPOSALPOL.fields_by_name['proposal_pol']._options = None
    _PROPOSALPOL.fields_by_name['proposal_pol']._serialized_options = b'\xc8\xde\x1f\x00'
    _BLOCKPART.fields_by_name['part']._options = None
    _BLOCKPART.fields_by_name['part']._serialized_options = b'\xc8\xde\x1f\x00'
    _VOTESETMAJ23.fields_by_name['block_id']._options = None
    _VOTESETMAJ23.fields_by_name['block_id']._serialized_options = b'\xe2\xde\x1f\x07BlockID\xc8\xde\x1f\x00'
    _VOTESETBITS.fields_by_name['block_id']._options = None
    _VOTESETBITS.fields_by_name['block_id']._serialized_options = b'\xe2\xde\x1f\x07BlockID\xc8\xde\x1f\x00'
    _VOTESETBITS.fields_by_name['votes']._options = None
    _VOTESETBITS.fields_by_name['votes']._serialized_options = b'\xc8\xde\x1f\x00'
    _NEWROUNDSTEP._serialized_start = 144
    _NEWROUNDSTEP._serialized_end = 264
    _NEWVALIDBLOCK._serialized_start = 267
    _NEWVALIDBLOCK._serialized_end = 455
    _PROPOSAL._serialized_start = 457
    _PROPOSAL._serialized_end = 519
    _PROPOSALPOL._serialized_start = 521
    _PROPOSALPOL._serialized_end = 638
    _BLOCKPART._serialized_start = 640
    _BLOCKPART._serialized_end = 726
    _VOTE._serialized_start = 728
    _VOTE._serialized_end = 772
    _HASVOTE._serialized_start = 774
    _HASVOTE._serialized_end = 876
    _VOTESETMAJ23._serialized_start = 879
    _VOTESETMAJ23._serialized_end = 1033
    _VOTESETBITS._serialized_start = 1036
    _VOTESETBITS._serialized_end = 1242
    _MESSAGE._serialized_start = 1245
    _MESSAGE._serialized_end = 1770




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ibc/applications/interchain_accounts/v1/account.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x19cosmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/auth/v1beta1/auth.proto"\xb9\x01\n\x11InterchainAccount\x12S\n\x0cbase_account\x18\x01 \x01(\x0b2 .cosmos.auth.v1beta1.BaseAccountB\x1b\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:"base_account"\x12/\n\raccount_owner\x18\x02 \x01(\tB\x18\xf2\xde\x1f\x14yaml:"account_owner":\x1e\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xca\xb4-\x12InterchainAccountIBGZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.account_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'ZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/types'
    _INTERCHAINACCOUNT.fields_by_name['base_account']._options = None
    _INTERCHAINACCOUNT.fields_by_name['base_account']._serialized_options = b'\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:"base_account"'
    _INTERCHAINACCOUNT.fields_by_name['account_owner']._options = None
    _INTERCHAINACCOUNT.fields_by_name['account_owner']._serialized_options = b'\xf2\xde\x1f\x14yaml:"account_owner"'
    _INTERCHAINACCOUNT._options = None
    _INTERCHAINACCOUNT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xca\xb4-\x12InterchainAccountI'
    _INTERCHAINACCOUNT._serialized_start = 180
    _INTERCHAINACCOUNT._serialized_end = 365




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import bandwidth_pb2 as _bandwidth_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Session(_message.Message):
    __slots__ = ['address', 'bandwidth', 'duration', 'id', 'inactive_at', 'node_address', 'status', 'status_at', 'subscription_id']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_AT_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    bandwidth: _bandwidth_pb2.Bandwidth
    duration: _duration_pb2.Duration
    id: int
    inactive_at: _timestamp_pb2.Timestamp
    node_address: str
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp
    subscription_id: int

    def __init__(self, id: _Optional[int]=..., subscription_id: _Optional[int]=..., node_address: _Optional[str]=..., address: _Optional[str]=..., bandwidth: _Optional[_Union[(_bandwidth_pb2.Bandwidth, _Mapping)]]=..., duration: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., inactive_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=..., status_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...



import argparse
import os
import re
import subprocess
import sys
import logging

parser = argparse.ArgumentParser(description='Aggregate all protobuf files')
parser.add_argument('-p', '--package_name', type=str, default="cosmospy_protobuf", help="Name for the package to build. This will aggregate all files in the src/{package_name} folder")
args = parser.parse_args()


package_name = 'src/' + args.package_name
logging.basicConfig(format='%(asctime)s - %(levelname)s:%(message)s', level=logging.DEBUG)
absolute_path = os.path.abspath(package_name)

def run_protoc(filepath):
    if os.path.basename(filepath) in ["query.proto", "querier.proto", "service.proto"]:
        cmd = [sys.executable, '-m', 'grpc_tools.protoc',
               '--proto_path', absolute_path,
               '--python_out', package_name,
               '--pyi_out', package_name,
               '--grpc_python_out', package_name,
               filepath]
        logging.info(f"Compiling proto and grpc file: {filepath}")
    else:
        cmd = [sys.executable, '-m', 'grpc_tools.protoc',
               f'--proto_path={absolute_path}',
               f'--python_out={package_name}',
               f'--pyi_out={package_name}',
               filepath]
        logging.info(f"Compiling proto file: {filepath}")

    subprocess.run(cmd)


def fix_proto_imports(filepath):
    logging.info(f"Fixing file at: {filepath}")
    cmd = [sys.executable, '-m', 'protoletariat',
           '--create-package', '--in-place',
           '--python-out', package_name,
           'protoc', f'--proto-path={absolute_path}',
           filepath]
    subprocess.run(cmd)


def walk_through_project_and_compile_proto(directory):
    for root, dirs, files in os.walk(directory):
        for filename in files:
            if filename.endswith('.proto'):
                run_protoc(os.path.abspath(os.path.join(root, filename)))


def walk_through_project_and_fix_imports(directory):
    for root, dirs, files in os.walk(directory):
        for filename in files:
            if filename.endswith('.proto'):
                fix_proto_imports(os.path.abspath(os.path.join(root, filename)))
                logging.info(f"Fixed imports for {filename}")


def remove_all_compiled_python_files(directory):
    for root, dirs, files in os.walk(directory):
        for filename in files:
            if filename.endswith('.py') or filename.endswith('.pyi'):
                logging.info(f"Deleting {os.path.join(root, filename)}")
                os.remove(os.path.join(root, filename))

def rename_any_proto_imports(directory):
    for root, dirs, files in os.walk(directory):
        for filename in files:
            with open(os.path.join(root, filename), 'r') as file:
                lines = file.readlines()

            if 'import "google/protobuf/any.proto";\n' in lines:
                with open(os.path.join(root, filename), 'w') as file:
                    for line in lines:
                        file.write(re.sub(r'^import "google/protobuf/any.proto";\n', 'import "google/protobuf/cosmos_any.proto";\n', line))





#rename_any_proto_imports(package_name)
remove_all_compiled_python_files(package_name)
walk_through_project_and_compile_proto(package_name)
walk_through_project_and_fix_imports(package_name)




from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.abci import types_pb2 as _types_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class ABCIMessageLog(_message.Message):
    __slots__ = ['events', 'log', 'msg_index']
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    MSG_INDEX_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[StringEvent]
    log: str
    msg_index: int

    def __init__(self, msg_index: _Optional[int]=..., log: _Optional[str]=..., events: _Optional[_Iterable[_Union[(StringEvent, _Mapping)]]]=...) -> None:
        ...

class Attribute(_message.Message):
    __slots__ = ['key', 'value']
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str

    def __init__(self, key: _Optional[str]=..., value: _Optional[str]=...) -> None:
        ...

class GasInfo(_message.Message):
    __slots__ = ['gas_used', 'gas_wanted']
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    gas_used: int
    gas_wanted: int

    def __init__(self, gas_wanted: _Optional[int]=..., gas_used: _Optional[int]=...) -> None:
        ...

class MsgData(_message.Message):
    __slots__ = ['data', 'msg_type']
    DATA_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    msg_type: str

    def __init__(self, msg_type: _Optional[str]=..., data: _Optional[bytes]=...) -> None:
        ...

class Result(_message.Message):
    __slots__ = ['data', 'events', 'log']
    DATA_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    events: _containers.RepeatedCompositeFieldContainer[_types_pb2.Event]
    log: str

    def __init__(self, data: _Optional[bytes]=..., log: _Optional[str]=..., events: _Optional[_Iterable[_Union[(_types_pb2.Event, _Mapping)]]]=...) -> None:
        ...

class SearchTxsResult(_message.Message):
    __slots__ = ['count', 'limit', 'page_number', 'page_total', 'total_count', 'txs']
    COUNT_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    PAGE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOTAL_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    TXS_FIELD_NUMBER: _ClassVar[int]
    count: int
    limit: int
    page_number: int
    page_total: int
    total_count: int
    txs: _containers.RepeatedCompositeFieldContainer[TxResponse]

    def __init__(self, total_count: _Optional[int]=..., count: _Optional[int]=..., page_number: _Optional[int]=..., page_total: _Optional[int]=..., limit: _Optional[int]=..., txs: _Optional[_Iterable[_Union[(TxResponse, _Mapping)]]]=...) -> None:
        ...

class SimulationResponse(_message.Message):
    __slots__ = ['gas_info', 'result']
    GAS_INFO_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    gas_info: GasInfo
    result: Result

    def __init__(self, gas_info: _Optional[_Union[(GasInfo, _Mapping)]]=..., result: _Optional[_Union[(Result, _Mapping)]]=...) -> None:
        ...

class StringEvent(_message.Message):
    __slots__ = ['attributes', 'type']
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    attributes: _containers.RepeatedCompositeFieldContainer[Attribute]
    type: str

    def __init__(self, type: _Optional[str]=..., attributes: _Optional[_Iterable[_Union[(Attribute, _Mapping)]]]=...) -> None:
        ...

class TxMsgData(_message.Message):
    __slots__ = ['data']
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _containers.RepeatedCompositeFieldContainer[MsgData]

    def __init__(self, data: _Optional[_Iterable[_Union[(MsgData, _Mapping)]]]=...) -> None:
        ...

class TxResponse(_message.Message):
    __slots__ = ['code', 'codespace', 'data', 'events', 'gas_used', 'gas_wanted', 'height', 'info', 'logs', 'raw_log', 'timestamp', 'tx', 'txhash']
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    LOGS_FIELD_NUMBER: _ClassVar[int]
    RAW_LOG_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TXHASH_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    code: int
    codespace: str
    data: str
    events: _containers.RepeatedCompositeFieldContainer[_types_pb2.Event]
    gas_used: int
    gas_wanted: int
    height: int
    info: str
    logs: _containers.RepeatedCompositeFieldContainer[ABCIMessageLog]
    raw_log: str
    timestamp: str
    tx: _any_pb2.Any
    txhash: str

    def __init__(self, height: _Optional[int]=..., txhash: _Optional[str]=..., codespace: _Optional[str]=..., code: _Optional[int]=..., data: _Optional[str]=..., raw_log: _Optional[str]=..., logs: _Optional[_Iterable[_Union[(ABCIMessageLog, _Mapping)]]]=..., info: _Optional[str]=..., gas_wanted: _Optional[int]=..., gas_used: _Optional[int]=..., tx: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., timestamp: _Optional[str]=..., events: _Optional[_Iterable[_Union[(_types_pb2.Event, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/distribution/v1beta1/query.proto\x12\x1bcosmos.distribution.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto"\x14\n\x12QueryParamsRequest"P\n\x13QueryParamsResponse\x129\n\x06params\x18\x01 \x01(\x0b2#.cosmos.distribution.v1beta1.ParamsB\x04\xc8\xde\x1f\x00"D\n\'QueryValidatorOutstandingRewardsRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t"{\n(QueryValidatorOutstandingRewardsResponse\x12O\n\x07rewards\x18\x01 \x01(\x0b28.cosmos.distribution.v1beta1.ValidatorOutstandingRewardsB\x04\xc8\xde\x1f\x00"<\n\x1fQueryValidatorCommissionRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t"y\n QueryValidatorCommissionResponse\x12U\n\ncommission\x18\x01 \x01(\x0b2;.cosmos.distribution.v1beta1.ValidatorAccumulatedCommissionB\x04\xc8\xde\x1f\x00"\xaf\x01\n\x1cQueryValidatorSlashesRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x17\n\x0fstarting_height\x18\x02 \x01(\x04\x12\x15\n\rending_height\x18\x03 \x01(\x04\x12:\n\npagination\x18\x04 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01"\xa5\x01\n\x1dQueryValidatorSlashesResponse\x12G\n\x07slashes\x18\x01 \x03(\x0b20.cosmos.distribution.v1beta1.ValidatorSlashEventB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"_\n\x1dQueryDelegationRewardsRequest\x12\x19\n\x11delegator_address\x18\x01 \x01(\t\x12\x19\n\x11validator_address\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x84\x01\n\x1eQueryDelegationRewardsResponse\x12b\n\x07rewards\x18\x01 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinB3\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins"I\n"QueryDelegationTotalRewardsRequest\x12\x19\n\x11delegator_address\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xd6\x01\n#QueryDelegationTotalRewardsResponse\x12M\n\x07rewards\x18\x01 \x03(\x0b26.cosmos.distribution.v1beta1.DelegationDelegatorRewardB\x04\xc8\xde\x1f\x00\x12`\n\x05total\x18\x02 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinB3\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins"F\n\x1fQueryDelegatorValidatorsRequest\x12\x19\n\x11delegator_address\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"@\n QueryDelegatorValidatorsResponse\x12\x12\n\nvalidators\x18\x01 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"K\n$QueryDelegatorWithdrawAddressRequest\x12\x19\n\x11delegator_address\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"K\n%QueryDelegatorWithdrawAddressResponse\x12\x18\n\x10withdraw_address\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1b\n\x19QueryCommunityPoolRequest"}\n\x1aQueryCommunityPoolResponse\x12_\n\x04pool\x18\x01 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinB3\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x002\xd8\x0f\n\x05Query\x12\x98\x01\n\x06Params\x12/.cosmos.distribution.v1beta1.QueryParamsRequest\x1a0.cosmos.distribution.v1beta1.QueryParamsResponse"+\x82\xd3\xe4\x93\x02%\x12#/cosmos/distribution/v1beta1/params\x12\x83\x02\n\x1bValidatorOutstandingRewards\x12D.cosmos.distribution.v1beta1.QueryValidatorOutstandingRewardsRequest\x1aE.cosmos.distribution.v1beta1.QueryValidatorOutstandingRewardsResponse"W\x82\xd3\xe4\x93\x02Q\x12O/cosmos/distribution/v1beta1/validators/{validator_address}/outstanding_rewards\x12\xe2\x01\n\x13ValidatorCommission\x12<.cosmos.distribution.v1beta1.QueryValidatorCommissionRequest\x1a=.cosmos.distribution.v1beta1.QueryValidatorCommissionResponse"N\x82\xd3\xe4\x93\x02H\x12F/cosmos/distribution/v1beta1/validators/{validator_address}/commission\x12\xd6\x01\n\x10ValidatorSlashes\x129.cosmos.distribution.v1beta1.QueryValidatorSlashesRequest\x1a:.cosmos.distribution.v1beta1.QueryValidatorSlashesResponse"K\x82\xd3\xe4\x93\x02E\x12C/cosmos/distribution/v1beta1/validators/{validator_address}/slashes\x12\xed\x01\n\x11DelegationRewards\x12:.cosmos.distribution.v1beta1.QueryDelegationRewardsRequest\x1a;.cosmos.distribution.v1beta1.QueryDelegationRewardsResponse"_\x82\xd3\xe4\x93\x02Y\x12W/cosmos/distribution/v1beta1/delegators/{delegator_address}/rewards/{validator_address}\x12\xe8\x01\n\x16DelegationTotalRewards\x12?.cosmos.distribution.v1beta1.QueryDelegationTotalRewardsRequest\x1a@.cosmos.distribution.v1beta1.QueryDelegationTotalRewardsResponse"K\x82\xd3\xe4\x93\x02E\x12C/cosmos/distribution/v1beta1/delegators/{delegator_address}/rewards\x12\xe2\x01\n\x13DelegatorValidators\x12<.cosmos.distribution.v1beta1.QueryDelegatorValidatorsRequest\x1a=.cosmos.distribution.v1beta1.QueryDelegatorValidatorsResponse"N\x82\xd3\xe4\x93\x02H\x12F/cosmos/distribution/v1beta1/delegators/{delegator_address}/validators\x12\xf7\x01\n\x18DelegatorWithdrawAddress\x12A.cosmos.distribution.v1beta1.QueryDelegatorWithdrawAddressRequest\x1aB.cosmos.distribution.v1beta1.QueryDelegatorWithdrawAddressResponse"T\x82\xd3\xe4\x93\x02N\x12L/cosmos/distribution/v1beta1/delegators/{delegator_address}/withdraw_address\x12\xb5\x01\n\rCommunityPool\x126.cosmos.distribution.v1beta1.QueryCommunityPoolRequest\x1a7.cosmos.distribution.v1beta1.QueryCommunityPoolResponse"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/distribution/v1beta1/community_poolB3Z1github.com/cosmos/cosmos-sdk/x/distribution/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYVALIDATOROUTSTANDINGREWARDSRESPONSE.fields_by_name['rewards']._options = None
    _QUERYVALIDATOROUTSTANDINGREWARDSRESPONSE.fields_by_name['rewards']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYVALIDATORCOMMISSIONRESPONSE.fields_by_name['commission']._options = None
    _QUERYVALIDATORCOMMISSIONRESPONSE.fields_by_name['commission']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYVALIDATORSLASHESREQUEST._options = None
    _QUERYVALIDATORSLASHESREQUEST._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x01'
    _QUERYVALIDATORSLASHESRESPONSE.fields_by_name['slashes']._options = None
    _QUERYVALIDATORSLASHESRESPONSE.fields_by_name['slashes']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDELEGATIONREWARDSREQUEST._options = None
    _QUERYDELEGATIONREWARDSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATIONREWARDSRESPONSE.fields_by_name['rewards']._options = None
    _QUERYDELEGATIONREWARDSRESPONSE.fields_by_name['rewards']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins'
    _QUERYDELEGATIONTOTALREWARDSREQUEST._options = None
    _QUERYDELEGATIONTOTALREWARDSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATIONTOTALREWARDSRESPONSE.fields_by_name['rewards']._options = None
    _QUERYDELEGATIONTOTALREWARDSRESPONSE.fields_by_name['rewards']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYDELEGATIONTOTALREWARDSRESPONSE.fields_by_name['total']._options = None
    _QUERYDELEGATIONTOTALREWARDSRESPONSE.fields_by_name['total']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins'
    _QUERYDELEGATORVALIDATORSREQUEST._options = None
    _QUERYDELEGATORVALIDATORSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATORVALIDATORSRESPONSE._options = None
    _QUERYDELEGATORVALIDATORSRESPONSE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATORWITHDRAWADDRESSREQUEST._options = None
    _QUERYDELEGATORWITHDRAWADDRESSREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYDELEGATORWITHDRAWADDRESSRESPONSE._options = None
    _QUERYDELEGATORWITHDRAWADDRESSRESPONSE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYCOMMUNITYPOOLRESPONSE.fields_by_name['pool']._options = None
    _QUERYCOMMUNITYPOOLRESPONSE.fields_by_name['pool']._serialized_options = b'\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02%\x12#/cosmos/distribution/v1beta1/params'
    _QUERY.methods_by_name['ValidatorOutstandingRewards']._options = None
    _QUERY.methods_by_name['ValidatorOutstandingRewards']._serialized_options = b'\x82\xd3\xe4\x93\x02Q\x12O/cosmos/distribution/v1beta1/validators/{validator_address}/outstanding_rewards'
    _QUERY.methods_by_name['ValidatorCommission']._options = None
    _QUERY.methods_by_name['ValidatorCommission']._serialized_options = b'\x82\xd3\xe4\x93\x02H\x12F/cosmos/distribution/v1beta1/validators/{validator_address}/commission'
    _QUERY.methods_by_name['ValidatorSlashes']._options = None
    _QUERY.methods_by_name['ValidatorSlashes']._serialized_options = b'\x82\xd3\xe4\x93\x02E\x12C/cosmos/distribution/v1beta1/validators/{validator_address}/slashes'
    _QUERY.methods_by_name['DelegationRewards']._options = None
    _QUERY.methods_by_name['DelegationRewards']._serialized_options = b'\x82\xd3\xe4\x93\x02Y\x12W/cosmos/distribution/v1beta1/delegators/{delegator_address}/rewards/{validator_address}'
    _QUERY.methods_by_name['DelegationTotalRewards']._options = None
    _QUERY.methods_by_name['DelegationTotalRewards']._serialized_options = b'\x82\xd3\xe4\x93\x02E\x12C/cosmos/distribution/v1beta1/delegators/{delegator_address}/rewards'
    _QUERY.methods_by_name['DelegatorValidators']._options = None
    _QUERY.methods_by_name['DelegatorValidators']._serialized_options = b'\x82\xd3\xe4\x93\x02H\x12F/cosmos/distribution/v1beta1/delegators/{delegator_address}/validators'
    _QUERY.methods_by_name['DelegatorWithdrawAddress']._options = None
    _QUERY.methods_by_name['DelegatorWithdrawAddress']._serialized_options = b'\x82\xd3\xe4\x93\x02N\x12L/cosmos/distribution/v1beta1/delegators/{delegator_address}/withdraw_address'
    _QUERY.methods_by_name['CommunityPool']._options = None
    _QUERY.methods_by_name['CommunityPool']._serialized_options = b'\x82\xd3\xe4\x93\x02-\x12+/cosmos/distribution/v1beta1/community_pool'
    _QUERYPARAMSREQUEST._serialized_start = 248
    _QUERYPARAMSREQUEST._serialized_end = 268
    _QUERYPARAMSRESPONSE._serialized_start = 270
    _QUERYPARAMSRESPONSE._serialized_end = 350
    _QUERYVALIDATOROUTSTANDINGREWARDSREQUEST._serialized_start = 352
    _QUERYVALIDATOROUTSTANDINGREWARDSREQUEST._serialized_end = 420
    _QUERYVALIDATOROUTSTANDINGREWARDSRESPONSE._serialized_start = 422
    _QUERYVALIDATOROUTSTANDINGREWARDSRESPONSE._serialized_end = 545
    _QUERYVALIDATORCOMMISSIONREQUEST._serialized_start = 547
    _QUERYVALIDATORCOMMISSIONREQUEST._serialized_end = 607
    _QUERYVALIDATORCOMMISSIONRESPONSE._serialized_start = 609
    _QUERYVALIDATORCOMMISSIONRESPONSE._serialized_end = 730
    _QUERYVALIDATORSLASHESREQUEST._serialized_start = 733
    _QUERYVALIDATORSLASHESREQUEST._serialized_end = 908
    _QUERYVALIDATORSLASHESRESPONSE._serialized_start = 911
    _QUERYVALIDATORSLASHESRESPONSE._serialized_end = 1076
    _QUERYDELEGATIONREWARDSREQUEST._serialized_start = 1078
    _QUERYDELEGATIONREWARDSREQUEST._serialized_end = 1173
    _QUERYDELEGATIONREWARDSRESPONSE._serialized_start = 1176
    _QUERYDELEGATIONREWARDSRESPONSE._serialized_end = 1308
    _QUERYDELEGATIONTOTALREWARDSREQUEST._serialized_start = 1310
    _QUERYDELEGATIONTOTALREWARDSREQUEST._serialized_end = 1383
    _QUERYDELEGATIONTOTALREWARDSRESPONSE._serialized_start = 1386
    _QUERYDELEGATIONTOTALREWARDSRESPONSE._serialized_end = 1600
    _QUERYDELEGATORVALIDATORSREQUEST._serialized_start = 1602
    _QUERYDELEGATORVALIDATORSREQUEST._serialized_end = 1672
    _QUERYDELEGATORVALIDATORSRESPONSE._serialized_start = 1674
    _QUERYDELEGATORVALIDATORSRESPONSE._serialized_end = 1738
    _QUERYDELEGATORWITHDRAWADDRESSREQUEST._serialized_start = 1740
    _QUERYDELEGATORWITHDRAWADDRESSREQUEST._serialized_end = 1815
    _QUERYDELEGATORWITHDRAWADDRESSRESPONSE._serialized_start = 1817
    _QUERYDELEGATORWITHDRAWADDRESSRESPONSE._serialized_end = 1892
    _QUERYCOMMUNITYPOOLREQUEST._serialized_start = 1894
    _QUERYCOMMUNITYPOOLREQUEST._serialized_end = 1921
    _QUERYCOMMUNITYPOOLRESPONSE._serialized_start = 1923
    _QUERYCOMMUNITYPOOLRESPONSE._serialized_end = 2048
    _QUERY._serialized_start = 2051
    _QUERY._serialized_end = 4059




from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import any_pb2 as _any_pb2
from sentinel.subscription.v2 import allocation_pb2 as _allocation_pb2
from sentinel.subscription.v2 import params_pb2 as _params_pb2
from sentinel.subscription.v2 import payout_pb2 as _payout_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryAllocationRequest(_message.Message):
    __slots__ = ['address', 'id']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int

    def __init__(self, id: _Optional[int]=..., address: _Optional[str]=...) -> None:
        ...

class QueryAllocationResponse(_message.Message):
    __slots__ = ['allocation']
    ALLOCATION_FIELD_NUMBER: _ClassVar[int]
    allocation: _allocation_pb2.Allocation

    def __init__(self, allocation: _Optional[_Union[(_allocation_pb2.Allocation, _Mapping)]]=...) -> None:
        ...

class QueryAllocationsRequest(_message.Message):
    __slots__ = ['id', 'pagination']
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    id: int
    pagination: _pagination_pb2.PageRequest

    def __init__(self, id: _Optional[int]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryAllocationsResponse(_message.Message):
    __slots__ = ['allocations', 'pagination']
    ALLOCATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    allocations: _containers.RepeatedCompositeFieldContainer[_allocation_pb2.Allocation]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, allocations: _Optional[_Iterable[_Union[(_allocation_pb2.Allocation, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryParamsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryParamsResponse(_message.Message):
    __slots__ = ['params']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params

    def __init__(self, params: _Optional[_Union[(_params_pb2.Params, _Mapping)]]=...) -> None:
        ...

class QueryPayoutRequest(_message.Message):
    __slots__ = ['id']
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int

    def __init__(self, id: _Optional[int]=...) -> None:
        ...

class QueryPayoutResponse(_message.Message):
    __slots__ = ['payout']
    PAYOUT_FIELD_NUMBER: _ClassVar[int]
    payout: _payout_pb2.Payout

    def __init__(self, payout: _Optional[_Union[(_payout_pb2.Payout, _Mapping)]]=...) -> None:
        ...

class QueryPayoutsForAccountRequest(_message.Message):
    __slots__ = ['address', 'pagination']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, address: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryPayoutsForAccountResponse(_message.Message):
    __slots__ = ['pagination', 'payouts']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PAYOUTS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    payouts: _containers.RepeatedCompositeFieldContainer[_payout_pb2.Payout]

    def __init__(self, payouts: _Optional[_Iterable[_Union[(_payout_pb2.Payout, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryPayoutsForNodeRequest(_message.Message):
    __slots__ = ['address', 'pagination']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, address: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryPayoutsForNodeResponse(_message.Message):
    __slots__ = ['pagination', 'payouts']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PAYOUTS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    payouts: _containers.RepeatedCompositeFieldContainer[_payout_pb2.Payout]

    def __init__(self, payouts: _Optional[_Iterable[_Union[(_payout_pb2.Payout, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryPayoutsRequest(_message.Message):
    __slots__ = ['pagination']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest

    def __init__(self, pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryPayoutsResponse(_message.Message):
    __slots__ = ['pagination', 'payouts']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PAYOUTS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    payouts: _containers.RepeatedCompositeFieldContainer[_payout_pb2.Payout]

    def __init__(self, payouts: _Optional[_Iterable[_Union[(_payout_pb2.Payout, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionRequest(_message.Message):
    __slots__ = ['id']
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int

    def __init__(self, id: _Optional[int]=...) -> None:
        ...

class QuerySubscriptionResponse(_message.Message):
    __slots__ = ['subscription']
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    subscription: _any_pb2.Any

    def __init__(self, subscription: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionsForAccountRequest(_message.Message):
    __slots__ = ['address', 'pagination']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, address: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionsForAccountResponse(_message.Message):
    __slots__ = ['pagination', 'subscriptions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    subscriptions: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]

    def __init__(self, subscriptions: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionsForNodeRequest(_message.Message):
    __slots__ = ['address', 'pagination']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, address: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionsForNodeResponse(_message.Message):
    __slots__ = ['pagination', 'subscriptions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    subscriptions: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]

    def __init__(self, subscriptions: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionsForPlanRequest(_message.Message):
    __slots__ = ['id', 'pagination']
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    id: int
    pagination: _pagination_pb2.PageRequest

    def __init__(self, id: _Optional[int]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionsForPlanResponse(_message.Message):
    __slots__ = ['pagination', 'subscriptions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    subscriptions: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]

    def __init__(self, subscriptions: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionsRequest(_message.Message):
    __slots__ = ['pagination']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest

    def __init__(self, pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySubscriptionsResponse(_message.Message):
    __slots__ = ['pagination', 'subscriptions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    subscriptions: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]

    def __init__(self, subscriptions: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/evidence/v1beta1/genesis.proto\x12\x17cosmos.evidence.v1beta1\x1a\x19google/protobuf/any.proto"6\n\x0cGenesisState\x12&\n\x08evidence\x18\x01 \x03(\x0b2\x14.google.protobuf.AnyB/Z-github.com/cosmos/cosmos-sdk/x/evidence/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types'
    _GENESISSTATE._serialized_start = 93
    _GENESISSTATE._serialized_end = 147




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class PageRequest(_message.Message):
    __slots__ = ['count_total', 'key', 'limit', 'offset', 'reverse']
    COUNT_TOTAL_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    count_total: bool
    key: bytes
    limit: int
    offset: int
    reverse: bool

    def __init__(self, key: _Optional[bytes]=..., offset: _Optional[int]=..., limit: _Optional[int]=..., count_total: bool=..., reverse: bool=...) -> None:
        ...

class PageResponse(_message.Message):
    __slots__ = ['next_key', 'total']
    NEXT_KEY_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    next_key: bytes
    total: int

    def __init__(self, next_key: _Optional[bytes]=..., total: _Optional[int]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.params.v1beta1 import params_pb2 as _params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ['key', 'subspace']
    KEY_FIELD_NUMBER: _ClassVar[int]
    SUBSPACE_FIELD_NUMBER: _ClassVar[int]
    key: str
    subspace: str

    def __init__(self, subspace: _Optional[str]=..., key: _Optional[str]=...) -> None:
        ...

class QueryParamsResponse(_message.Message):
    __slots__ = ['param']
    PARAM_FIELD_NUMBER: _ClassVar[int]
    param: _params_pb2.ParamChange

    def __init__(self, param: _Optional[_Union[(_params_pb2.ParamChange, _Mapping)]]=...) -> None:
        ...




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Node(_message.Message):
    __slots__ = ['address', 'gigabyte_prices', 'hourly_prices', 'inactive_at', 'remote_url', 'status', 'status_at']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    GIGABYTE_PRICES_FIELD_NUMBER: _ClassVar[int]
    HOURLY_PRICES_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_AT_FIELD_NUMBER: _ClassVar[int]
    REMOTE_URL_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    gigabyte_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    hourly_prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    inactive_at: _timestamp_pb2.Timestamp
    remote_url: str
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp

    def __init__(self, address: _Optional[str]=..., gigabyte_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., hourly_prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=..., remote_url: _Optional[str]=..., inactive_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=..., status_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class DefaultNodeInfo(_message.Message):
    __slots__ = ['channels', 'default_node_id', 'listen_addr', 'moniker', 'network', 'other', 'protocol_version', 'version']
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_NODE_ID_FIELD_NUMBER: _ClassVar[int]
    LISTEN_ADDR_FIELD_NUMBER: _ClassVar[int]
    MONIKER_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    OTHER_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    channels: bytes
    default_node_id: str
    listen_addr: str
    moniker: str
    network: str
    other: DefaultNodeInfoOther
    protocol_version: ProtocolVersion
    version: str

    def __init__(self, protocol_version: _Optional[_Union[(ProtocolVersion, _Mapping)]]=..., default_node_id: _Optional[str]=..., listen_addr: _Optional[str]=..., network: _Optional[str]=..., version: _Optional[str]=..., channels: _Optional[bytes]=..., moniker: _Optional[str]=..., other: _Optional[_Union[(DefaultNodeInfoOther, _Mapping)]]=...) -> None:
        ...

class DefaultNodeInfoOther(_message.Message):
    __slots__ = ['rpc_address', 'tx_index']
    RPC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TX_INDEX_FIELD_NUMBER: _ClassVar[int]
    rpc_address: str
    tx_index: str

    def __init__(self, tx_index: _Optional[str]=..., rpc_address: _Optional[str]=...) -> None:
        ...

class NetAddress(_message.Message):
    __slots__ = ['id', 'ip', 'port']
    ID_FIELD_NUMBER: _ClassVar[int]
    IP_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    id: str
    ip: str
    port: int

    def __init__(self, id: _Optional[str]=..., ip: _Optional[str]=..., port: _Optional[int]=...) -> None:
        ...

class ProtocolVersion(_message.Message):
    __slots__ = ['app', 'block', 'p2p']
    APP_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    P2P_FIELD_NUMBER: _ClassVar[int]
    app: int
    block: int
    p2p: int

    def __init__(self, p2p: _Optional[int]=..., block: _Optional[int]=..., app: _Optional[int]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/vesting/v1beta1/vesting.proto\x12\x16cosmos.vesting.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1ecosmos/auth/v1beta1/auth.proto"\x89\x04\n\x12BaseVestingAccount\x12<\n\x0cbase_account\x18\x01 \x01(\x0b2 .cosmos.auth.v1beta1.BaseAccountB\x04\xd0\xde\x1f\x01\x12\x80\x01\n\x10original_vesting\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinBK\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x17yaml:"original_vesting"\x12|\n\x0edelegated_free\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinBI\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x15yaml:"delegated_free"\x12\x82\x01\n\x11delegated_vesting\x18\x04 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinBL\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x18yaml:"delegated_vesting"\x12%\n\x08end_time\x18\x05 \x01(\x03B\x13\xf2\xde\x1f\x0fyaml:"end_time":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00"\x9f\x01\n\x18ContinuousVestingAccount\x12N\n\x14base_vesting_account\x18\x01 \x01(\x0b2*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01\x12)\n\nstart_time\x18\x02 \x01(\x03B\x15\xf2\xde\x1f\x11yaml:"start_time":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00"q\n\x15DelayedVestingAccount\x12N\n\x14base_vesting_account\x18\x01 \x01(\x0b2*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00"{\n\x06Period\x12\x0e\n\x06length\x18\x01 \x01(\x03\x12[\n\x06amount\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x04\x98\xa0\x1f\x00"\xf6\x01\n\x16PeriodicVestingAccount\x12N\n\x14base_vesting_account\x18\x01 \x01(\x0b2*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01\x12)\n\nstart_time\x18\x02 \x01(\x03B\x15\xf2\xde\x1f\x11yaml:"start_time"\x12W\n\x0fvesting_periods\x18\x03 \x03(\x0b2\x1e.cosmos.vesting.v1beta1.PeriodB\x1e\xf2\xde\x1f\x16yaml:"vesting_periods"\xc8\xde\x1f\x00:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00"r\n\x16PermanentLockedAccount\x12N\n\x14base_vesting_account\x18\x01 \x01(\x0b2*.cosmos.vesting.v1beta1.BaseVestingAccountB\x04\xd0\xde\x1f\x01:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00B3Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.v1beta1.vesting_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types'
    _BASEVESTINGACCOUNT.fields_by_name['base_account']._options = None
    _BASEVESTINGACCOUNT.fields_by_name['base_account']._serialized_options = b'\xd0\xde\x1f\x01'
    _BASEVESTINGACCOUNT.fields_by_name['original_vesting']._options = None
    _BASEVESTINGACCOUNT.fields_by_name['original_vesting']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x17yaml:"original_vesting"'
    _BASEVESTINGACCOUNT.fields_by_name['delegated_free']._options = None
    _BASEVESTINGACCOUNT.fields_by_name['delegated_free']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x15yaml:"delegated_free"'
    _BASEVESTINGACCOUNT.fields_by_name['delegated_vesting']._options = None
    _BASEVESTINGACCOUNT.fields_by_name['delegated_vesting']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x18yaml:"delegated_vesting"'
    _BASEVESTINGACCOUNT.fields_by_name['end_time']._options = None
    _BASEVESTINGACCOUNT.fields_by_name['end_time']._serialized_options = b'\xf2\xde\x1f\x0fyaml:"end_time"'
    _BASEVESTINGACCOUNT._options = None
    _BASEVESTINGACCOUNT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _CONTINUOUSVESTINGACCOUNT.fields_by_name['base_vesting_account']._options = None
    _CONTINUOUSVESTINGACCOUNT.fields_by_name['base_vesting_account']._serialized_options = b'\xd0\xde\x1f\x01'
    _CONTINUOUSVESTINGACCOUNT.fields_by_name['start_time']._options = None
    _CONTINUOUSVESTINGACCOUNT.fields_by_name['start_time']._serialized_options = b'\xf2\xde\x1f\x11yaml:"start_time"'
    _CONTINUOUSVESTINGACCOUNT._options = None
    _CONTINUOUSVESTINGACCOUNT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _DELAYEDVESTINGACCOUNT.fields_by_name['base_vesting_account']._options = None
    _DELAYEDVESTINGACCOUNT.fields_by_name['base_vesting_account']._serialized_options = b'\xd0\xde\x1f\x01'
    _DELAYEDVESTINGACCOUNT._options = None
    _DELAYEDVESTINGACCOUNT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _PERIOD.fields_by_name['amount']._options = None
    _PERIOD.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _PERIOD._options = None
    _PERIOD._serialized_options = b'\x98\xa0\x1f\x00'
    _PERIODICVESTINGACCOUNT.fields_by_name['base_vesting_account']._options = None
    _PERIODICVESTINGACCOUNT.fields_by_name['base_vesting_account']._serialized_options = b'\xd0\xde\x1f\x01'
    _PERIODICVESTINGACCOUNT.fields_by_name['start_time']._options = None
    _PERIODICVESTINGACCOUNT.fields_by_name['start_time']._serialized_options = b'\xf2\xde\x1f\x11yaml:"start_time"'
    _PERIODICVESTINGACCOUNT.fields_by_name['vesting_periods']._options = None
    _PERIODICVESTINGACCOUNT.fields_by_name['vesting_periods']._serialized_options = b'\xf2\xde\x1f\x16yaml:"vesting_periods"\xc8\xde\x1f\x00'
    _PERIODICVESTINGACCOUNT._options = None
    _PERIODICVESTINGACCOUNT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _PERMANENTLOCKEDACCOUNT.fields_by_name['base_vesting_account']._options = None
    _PERMANENTLOCKEDACCOUNT.fields_by_name['base_vesting_account']._serialized_options = b'\xd0\xde\x1f\x01'
    _PERMANENTLOCKEDACCOUNT._options = None
    _PERMANENTLOCKEDACCOUNT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _BASEVESTINGACCOUNT._serialized_start = 151
    _BASEVESTINGACCOUNT._serialized_end = 672
    _CONTINUOUSVESTINGACCOUNT._serialized_start = 675
    _CONTINUOUSVESTINGACCOUNT._serialized_end = 834
    _DELAYEDVESTINGACCOUNT._serialized_start = 836
    _DELAYEDVESTINGACCOUNT._serialized_end = 949
    _PERIOD._serialized_start = 951
    _PERIOD._serialized_end = 1074
    _PERIODICVESTINGACCOUNT._serialized_start = 1077
    _PERIODICVESTINGACCOUNT._serialized_end = 1323
    _PERMANENTLOCKEDACCOUNT._serialized_start = 1325
    _PERMANENTLOCKEDACCOUNT._serialized_end = 1439




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/genesis.proto\x12\x16cosmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a$cosmos/staking/v1beta1/staking.proto"\xdd\x04\n\x0cGenesisState\x124\n\x06params\x18\x01 \x01(\x0b2\x1e.cosmos.staking.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12c\n\x10last_total_power\x18\x02 \x01(\x0cBI\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:"last_total_power"\xc8\xde\x1f\x00\x12o\n\x15last_validator_powers\x18\x03 \x03(\x0b2*.cosmos.staking.v1beta1.LastValidatorPowerB$\xf2\xde\x1f\x1cyaml:"last_validator_powers"\xc8\xde\x1f\x00\x12;\n\nvalidators\x18\x04 \x03(\x0b2!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12=\n\x0bdelegations\x18\x05 \x03(\x0b2".cosmos.staking.v1beta1.DelegationB\x04\xc8\xde\x1f\x00\x12p\n\x15unbonding_delegations\x18\x06 \x03(\x0b2+.cosmos.staking.v1beta1.UnbondingDelegationB$\xf2\xde\x1f\x1cyaml:"unbonding_delegations"\xc8\xde\x1f\x00\x12A\n\rredelegations\x18\x07 \x03(\x0b2$.cosmos.staking.v1beta1.RedelegationB\x04\xc8\xde\x1f\x00\x12\x10\n\x08exported\x18\x08 \x01(\x08">\n\x12LastValidatorPower\x12\x0f\n\x07address\x18\x01 \x01(\t\x12\r\n\x05power\x18\x02 \x01(\x03:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00B.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['last_total_power']._options = None
    _GENESISSTATE.fields_by_name['last_total_power']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:"last_total_power"\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['last_validator_powers']._options = None
    _GENESISSTATE.fields_by_name['last_validator_powers']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"last_validator_powers"\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['validators']._options = None
    _GENESISSTATE.fields_by_name['validators']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['delegations']._options = None
    _GENESISSTATE.fields_by_name['delegations']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['unbonding_delegations']._options = None
    _GENESISSTATE.fields_by_name['unbonding_delegations']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"unbonding_delegations"\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['redelegations']._options = None
    _GENESISSTATE.fields_by_name['redelegations']._serialized_options = b'\xc8\xde\x1f\x00'
    _LASTVALIDATORPOWER._options = None
    _LASTVALIDATORPOWER._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _GENESISSTATE._serialized_start = 125
    _GENESISSTATE._serialized_end = 730
    _LASTVALIDATORPOWER._serialized_start = 732
    _LASTVALIDATORPOWER._serialized_end = 794




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.feegrant.v1beta1 import feegrant_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_feegrant__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/feegrant/v1beta1/genesis.proto\x12\x17cosmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/feegrant/v1beta1/feegrant.proto"H\n\x0cGenesisState\x128\n\nallowances\x18\x01 \x03(\x0b2\x1e.cosmos.feegrant.v1beta1.GrantB\x04\xc8\xde\x1f\x00B)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"Z'github.com/cosmos/cosmos-sdk/x/feegrant"
    _GENESISSTATE.fields_by_name['allowances']._options = None
    _GENESISSTATE.fields_by_name['allowances']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE._serialized_start = 128
    _GENESISSTATE._serialized_end = 200




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ibc/applications/transfer/v1/transfer.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto".\n\nDenomTrace\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nbase_denom\x18\x02 \x01(\t"l\n\x06Params\x12-\n\x0csend_enabled\x18\x01 \x01(\x08B\x17\xf2\xde\x1f\x13yaml:"send_enabled"\x123\n\x0freceive_enabled\x18\x02 \x01(\x08B\x1a\xf2\xde\x1f\x16yaml:"receive_enabled"B9Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.transfer_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v3/modules/apps/transfer/types'
    _PARAMS.fields_by_name['send_enabled']._options = None
    _PARAMS.fields_by_name['send_enabled']._serialized_options = b'\xf2\xde\x1f\x13yaml:"send_enabled"'
    _PARAMS.fields_by_name['receive_enabled']._options = None
    _PARAMS.fields_by_name['receive_enabled']._serialized_options = b'\xf2\xde\x1f\x16yaml:"receive_enabled"'
    _DENOMTRACE._serialized_start = 99
    _DENOMTRACE._serialized_end = 145
    _PARAMS._serialized_start = 147
    _PARAMS._serialized_end = 255




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ['controller_enabled']
    CONTROLLER_ENABLED_FIELD_NUMBER: _ClassVar[int]
    controller_enabled: bool

    def __init__(self, controller_enabled: bool=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentinel/node/v2/msg.proto\x12\x10sentinel.node.v2\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1esentinel/types/v1/status.proto"\x8e\x02\n\x12MsgRegisterRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12d\n\x0fgigabyte_prices\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12b\n\rhourly_prices\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12!\n\nremote_url\x18\x04 \x01(\tB\r\xe2\xde\x1f\tRemoteURL"\x93\x02\n\x17MsgUpdateDetailsRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12d\n\x0fgigabyte_prices\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12b\n\rhourly_prices\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12!\n\nremote_url\x18\x04 \x01(\tB\r\xe2\xde\x1f\tRemoteURL"P\n\x16MsgUpdateStatusRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e2\x19.sentinel.types.v1.Status"i\n\x13MsgSubscribeRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x14\n\x0cnode_address\x18\x02 \x01(\t\x12\x11\n\tgigabytes\x18\x03 \x01(\x03\x12\r\n\x05hours\x18\x04 \x01(\x03\x12\r\n\x05denom\x18\x05 \x01(\t"\x15\n\x13MsgRegisterResponse"\x1a\n\x18MsgUpdateDetailsResponse"\x19\n\x17MsgUpdateStatusResponse"\x16\n\x14MsgSubscribeResponse2\x9a\x03\n\nMsgService\x12Z\n\x0bMsgRegister\x12$.sentinel.node.v2.MsgRegisterRequest\x1a%.sentinel.node.v2.MsgRegisterResponse\x12i\n\x10MsgUpdateDetails\x12).sentinel.node.v2.MsgUpdateDetailsRequest\x1a*.sentinel.node.v2.MsgUpdateDetailsResponse\x12f\n\x0fMsgUpdateStatus\x12(.sentinel.node.v2.MsgUpdateStatusRequest\x1a).sentinel.node.v2.MsgUpdateStatusResponse\x12]\n\x0cMsgSubscribe\x12%.sentinel.node.v2.MsgSubscribeRequest\x1a&.sentinel.node.v2.MsgSubscribeResponseB7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.msg_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _MSGREGISTERREQUEST.fields_by_name['gigabyte_prices']._options = None
    _MSGREGISTERREQUEST.fields_by_name['gigabyte_prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGREGISTERREQUEST.fields_by_name['hourly_prices']._options = None
    _MSGREGISTERREQUEST.fields_by_name['hourly_prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGREGISTERREQUEST.fields_by_name['remote_url']._options = None
    _MSGREGISTERREQUEST.fields_by_name['remote_url']._serialized_options = b'\xe2\xde\x1f\tRemoteURL'
    _MSGUPDATEDETAILSREQUEST.fields_by_name['gigabyte_prices']._options = None
    _MSGUPDATEDETAILSREQUEST.fields_by_name['gigabyte_prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGUPDATEDETAILSREQUEST.fields_by_name['hourly_prices']._options = None
    _MSGUPDATEDETAILSREQUEST.fields_by_name['hourly_prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGUPDATEDETAILSREQUEST.fields_by_name['remote_url']._options = None
    _MSGUPDATEDETAILSREQUEST.fields_by_name['remote_url']._serialized_options = b'\xe2\xde\x1f\tRemoteURL'
    _MSGREGISTERREQUEST._serialized_start = 135
    _MSGREGISTERREQUEST._serialized_end = 405
    _MSGUPDATEDETAILSREQUEST._serialized_start = 408
    _MSGUPDATEDETAILSREQUEST._serialized_end = 683
    _MSGUPDATESTATUSREQUEST._serialized_start = 685
    _MSGUPDATESTATUSREQUEST._serialized_end = 765
    _MSGSUBSCRIBEREQUEST._serialized_start = 767
    _MSGSUBSCRIBEREQUEST._serialized_end = 872
    _MSGREGISTERRESPONSE._serialized_start = 874
    _MSGREGISTERRESPONSE._serialized_end = 895
    _MSGUPDATEDETAILSRESPONSE._serialized_start = 897
    _MSGUPDATEDETAILSRESPONSE._serialized_end = 923
    _MSGUPDATESTATUSRESPONSE._serialized_start = 925
    _MSGUPDATESTATUSRESPONSE._serialized_end = 950
    _MSGSUBSCRIBERESPONSE._serialized_start = 952
    _MSGSUBSCRIBERESPONSE._serialized_end = 974
    _MSGSERVICE._serialized_start = 977
    _MSGSERVICE._serialized_end = 1387




from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.staking.v1beta1 import staking_pb2 as _staking_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryDelegationRequest(_message.Message):
    __slots__ = ['delegator_addr', 'validator_addr']
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    validator_addr: str

    def __init__(self, delegator_addr: _Optional[str]=..., validator_addr: _Optional[str]=...) -> None:
        ...

class QueryDelegationResponse(_message.Message):
    __slots__ = ['delegation_response']
    DELEGATION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    delegation_response: _staking_pb2.DelegationResponse

    def __init__(self, delegation_response: _Optional[_Union[(_staking_pb2.DelegationResponse, _Mapping)]]=...) -> None:
        ...

class QueryDelegatorDelegationsRequest(_message.Message):
    __slots__ = ['delegator_addr', 'pagination']
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, delegator_addr: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryDelegatorDelegationsResponse(_message.Message):
    __slots__ = ['delegation_responses', 'pagination']
    DELEGATION_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegation_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.DelegationResponse]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, delegation_responses: _Optional[_Iterable[_Union[(_staking_pb2.DelegationResponse, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryDelegatorUnbondingDelegationsRequest(_message.Message):
    __slots__ = ['delegator_addr', 'pagination']
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, delegator_addr: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryDelegatorUnbondingDelegationsResponse(_message.Message):
    __slots__ = ['pagination', 'unbonding_responses']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    unbonding_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.UnbondingDelegation]

    def __init__(self, unbonding_responses: _Optional[_Iterable[_Union[(_staking_pb2.UnbondingDelegation, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryDelegatorValidatorRequest(_message.Message):
    __slots__ = ['delegator_addr', 'validator_addr']
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    validator_addr: str

    def __init__(self, delegator_addr: _Optional[str]=..., validator_addr: _Optional[str]=...) -> None:
        ...

class QueryDelegatorValidatorResponse(_message.Message):
    __slots__ = ['validator']
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    validator: _staking_pb2.Validator

    def __init__(self, validator: _Optional[_Union[(_staking_pb2.Validator, _Mapping)]]=...) -> None:
        ...

class QueryDelegatorValidatorsRequest(_message.Message):
    __slots__ = ['delegator_addr', 'pagination']
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, delegator_addr: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryDelegatorValidatorsResponse(_message.Message):
    __slots__ = ['pagination', 'validators']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    validators: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Validator]

    def __init__(self, validators: _Optional[_Iterable[_Union[(_staking_pb2.Validator, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryHistoricalInfoRequest(_message.Message):
    __slots__ = ['height']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int

    def __init__(self, height: _Optional[int]=...) -> None:
        ...

class QueryHistoricalInfoResponse(_message.Message):
    __slots__ = ['hist']
    HIST_FIELD_NUMBER: _ClassVar[int]
    hist: _staking_pb2.HistoricalInfo

    def __init__(self, hist: _Optional[_Union[(_staking_pb2.HistoricalInfo, _Mapping)]]=...) -> None:
        ...

class QueryParamsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryParamsResponse(_message.Message):
    __slots__ = ['params']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _staking_pb2.Params

    def __init__(self, params: _Optional[_Union[(_staking_pb2.Params, _Mapping)]]=...) -> None:
        ...

class QueryPoolRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryPoolResponse(_message.Message):
    __slots__ = ['pool']
    POOL_FIELD_NUMBER: _ClassVar[int]
    pool: _staking_pb2.Pool

    def __init__(self, pool: _Optional[_Union[(_staking_pb2.Pool, _Mapping)]]=...) -> None:
        ...

class QueryRedelegationsRequest(_message.Message):
    __slots__ = ['delegator_addr', 'dst_validator_addr', 'pagination', 'src_validator_addr']
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    DST_VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SRC_VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    dst_validator_addr: str
    pagination: _pagination_pb2.PageRequest
    src_validator_addr: str

    def __init__(self, delegator_addr: _Optional[str]=..., src_validator_addr: _Optional[str]=..., dst_validator_addr: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryRedelegationsResponse(_message.Message):
    __slots__ = ['pagination', 'redelegation_responses']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    REDELEGATION_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    redelegation_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.RedelegationResponse]

    def __init__(self, redelegation_responses: _Optional[_Iterable[_Union[(_staking_pb2.RedelegationResponse, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryUnbondingDelegationRequest(_message.Message):
    __slots__ = ['delegator_addr', 'validator_addr']
    DELEGATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    delegator_addr: str
    validator_addr: str

    def __init__(self, delegator_addr: _Optional[str]=..., validator_addr: _Optional[str]=...) -> None:
        ...

class QueryUnbondingDelegationResponse(_message.Message):
    __slots__ = ['unbond']
    UNBOND_FIELD_NUMBER: _ClassVar[int]
    unbond: _staking_pb2.UnbondingDelegation

    def __init__(self, unbond: _Optional[_Union[(_staking_pb2.UnbondingDelegation, _Mapping)]]=...) -> None:
        ...

class QueryValidatorDelegationsRequest(_message.Message):
    __slots__ = ['pagination', 'validator_addr']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    validator_addr: str

    def __init__(self, validator_addr: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryValidatorDelegationsResponse(_message.Message):
    __slots__ = ['delegation_responses', 'pagination']
    DELEGATION_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    delegation_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.DelegationResponse]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, delegation_responses: _Optional[_Iterable[_Union[(_staking_pb2.DelegationResponse, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryValidatorRequest(_message.Message):
    __slots__ = ['validator_addr']
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    validator_addr: str

    def __init__(self, validator_addr: _Optional[str]=...) -> None:
        ...

class QueryValidatorResponse(_message.Message):
    __slots__ = ['validator']
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    validator: _staking_pb2.Validator

    def __init__(self, validator: _Optional[_Union[(_staking_pb2.Validator, _Mapping)]]=...) -> None:
        ...

class QueryValidatorUnbondingDelegationsRequest(_message.Message):
    __slots__ = ['pagination', 'validator_addr']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDR_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    validator_addr: str

    def __init__(self, validator_addr: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryValidatorUnbondingDelegationsResponse(_message.Message):
    __slots__ = ['pagination', 'unbonding_responses']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    unbonding_responses: _containers.RepeatedCompositeFieldContainer[_staking_pb2.UnbondingDelegation]

    def __init__(self, unbonding_responses: _Optional[_Iterable[_Union[(_staking_pb2.UnbondingDelegation, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryValidatorsRequest(_message.Message):
    __slots__ = ['pagination', 'status']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    status: str

    def __init__(self, status: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryValidatorsResponse(_message.Message):
    __slots__ = ['pagination', 'validators']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    validators: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Validator]

    def __init__(self, validators: _Optional[_Iterable[_Union[(_staking_pb2.Validator, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+sentinel/subscription/v2/subscription.proto\x12\x18sentinel.subscription.v2\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esentinel/types/v1/status.proto"\xd6\x01\n\x10BaseSubscription\x12\x12\n\x02id\x18\x01 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07address\x18\x02 \x01(\t\x129\n\x0binactive_at\x18\x03 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12)\n\x06status\x18\x04 \x01(\x0e2\x19.sentinel.types.v1.Status\x127\n\tstatus_at\x18\x05 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01"\xbc\x01\n\x10NodeSubscription\x12>\n\x04base\x18\x01 \x01(\x0b2*.sentinel.subscription.v2.BaseSubscriptionB\x04\xd0\xde\x1f\x01\x12\x14\n\x0cnode_address\x18\x02 \x01(\t\x12\x11\n\tgigabytes\x18\x03 \x01(\x03\x12\r\n\x05hours\x18\x04 \x01(\x03\x120\n\x07deposit\x18\x05 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00"~\n\x10PlanSubscription\x12>\n\x04base\x18\x01 \x01(\x0b2*.sentinel.subscription.v2.BaseSubscriptionB\x04\xd0\xde\x1f\x01\x12\x1b\n\x07plan_id\x18\x02 \x01(\x04B\n\xe2\xde\x1f\x06PlanID\x12\r\n\x05denom\x18\x03 \x01(\t*}\n\x10SubscriptionType\x12)\n\x10TYPE_UNSPECIFIED\x10\x00\x1a\x13\x8a\x9d \x0fTypeUnspecified\x12\x1b\n\tTYPE_NODE\x10\x01\x1a\x0c\x8a\x9d \x08TypeNode\x12\x1b\n\tTYPE_PLAN\x10\x02\x1a\x0c\x8a\x9d \x08TypePlan\x1a\x04\x88\xa3\x1e\x00B?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.subscription_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _SUBSCRIPTIONTYPE._options = None
    _SUBSCRIPTIONTYPE._serialized_options = b'\x88\xa3\x1e\x00'
    _SUBSCRIPTIONTYPE.values_by_name['TYPE_UNSPECIFIED']._options = None
    _SUBSCRIPTIONTYPE.values_by_name['TYPE_UNSPECIFIED']._serialized_options = b'\x8a\x9d \x0fTypeUnspecified'
    _SUBSCRIPTIONTYPE.values_by_name['TYPE_NODE']._options = None
    _SUBSCRIPTIONTYPE.values_by_name['TYPE_NODE']._serialized_options = b'\x8a\x9d \x08TypeNode'
    _SUBSCRIPTIONTYPE.values_by_name['TYPE_PLAN']._options = None
    _SUBSCRIPTIONTYPE.values_by_name['TYPE_PLAN']._serialized_options = b'\x8a\x9d \x08TypePlan'
    _BASESUBSCRIPTION.fields_by_name['id']._options = None
    _BASESUBSCRIPTION.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _BASESUBSCRIPTION.fields_by_name['inactive_at']._options = None
    _BASESUBSCRIPTION.fields_by_name['inactive_at']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _BASESUBSCRIPTION.fields_by_name['status_at']._options = None
    _BASESUBSCRIPTION.fields_by_name['status_at']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _NODESUBSCRIPTION.fields_by_name['base']._options = None
    _NODESUBSCRIPTION.fields_by_name['base']._serialized_options = b'\xd0\xde\x1f\x01'
    _NODESUBSCRIPTION.fields_by_name['deposit']._options = None
    _NODESUBSCRIPTION.fields_by_name['deposit']._serialized_options = b'\xc8\xde\x1f\x00'
    _PLANSUBSCRIPTION.fields_by_name['base']._options = None
    _PLANSUBSCRIPTION.fields_by_name['base']._serialized_options = b'\xd0\xde\x1f\x01'
    _PLANSUBSCRIPTION.fields_by_name['plan_id']._options = None
    _PLANSUBSCRIPTION.fields_by_name['plan_id']._serialized_options = b'\xe2\xde\x1f\x06PlanID'
    _SUBSCRIPTIONTYPE._serialized_start = 728
    _SUBSCRIPTIONTYPE._serialized_end = 853
    _BASESUBSCRIPTION._serialized_start = 193
    _BASESUBSCRIPTION._serialized_end = 407
    _NODESUBSCRIPTION._serialized_start = 410
    _NODESUBSCRIPTION._serialized_end = 598
    _PLANSUBSCRIPTION._serialized_start = 600
    _PLANSUBSCRIPTION._serialized_end = 726




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from ....sentinel.provider.v2 import params_pb2 as sentinel_dot_provider_dot_v2_dot_params__pb2
from ....sentinel.provider.v2 import provider_pb2 as sentinel_dot_provider_dot_v2_dot_provider__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"sentinel/provider/v2/querier.proto\x12\x14sentinel.provider.v2\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a!sentinel/provider/v2/params.proto\x1a#sentinel/provider/v2/provider.proto"~\n\x15QueryProvidersRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest\x12)\n\x06status\x18\x02 \x01(\x0e2\x19.sentinel.types.v1.Status"\'\n\x14QueryProviderRequest\x12\x0f\n\x07address\x18\x01 \x01(\t"\x14\n\x12QueryParamsRequest"\x8e\x01\n\x16QueryProvidersResponse\x127\n\tproviders\x18\x01 \x03(\x0b2\x1e.sentinel.provider.v2.ProviderB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"O\n\x15QueryProviderResponse\x126\n\x08provider\x18\x01 \x01(\x0b2\x1e.sentinel.provider.v2.ProviderB\x04\xc8\xde\x1f\x00"I\n\x13QueryParamsResponse\x122\n\x06params\x18\x01 \x01(\x0b2\x1c.sentinel.provider.v2.ParamsB\x04\xc8\xde\x1f\x002\xb3\x03\n\x0cQueryService\x12\x88\x01\n\x0eQueryProviders\x12+.sentinel.provider.v2.QueryProvidersRequest\x1a,.sentinel.provider.v2.QueryProvidersResponse"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/sentinel/providers\x12\x8f\x01\n\rQueryProvider\x12*.sentinel.provider.v2.QueryProviderRequest\x1a+.sentinel.provider.v2.QueryProviderResponse"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/providers/{address}\x12\x85\x01\n\x0bQueryParams\x12(.sentinel.provider.v2.QueryParamsRequest\x1a).sentinel.provider.v2.QueryParamsResponse"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/params/providerB;Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.provider.v2.querier_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/sentinel-official/hub/x/provider/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _QUERYPROVIDERSRESPONSE.fields_by_name['providers']._options = None
    _QUERYPROVIDERSRESPONSE.fields_by_name['providers']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPROVIDERRESPONSE.fields_by_name['provider']._options = None
    _QUERYPROVIDERRESPONSE.fields_by_name['provider']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSERVICE.methods_by_name['QueryProviders']._options = None
    _QUERYSERVICE.methods_by_name['QueryProviders']._serialized_options = b'\x82\xd3\xe4\x93\x02\x15\x12\x13/sentinel/providers'
    _QUERYSERVICE.methods_by_name['QueryProvider']._options = None
    _QUERYSERVICE.methods_by_name['QueryProvider']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1f\x12\x1d/sentinel/providers/{address}'
    _QUERYSERVICE.methods_by_name['QueryParams']._options = None
    _QUERYSERVICE.methods_by_name['QueryParams']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1b\x12\x19/sentinel/params/provider'
    _QUERYPROVIDERSREQUEST._serialized_start = 260
    _QUERYPROVIDERSREQUEST._serialized_end = 386
    _QUERYPROVIDERREQUEST._serialized_start = 388
    _QUERYPROVIDERREQUEST._serialized_end = 427
    _QUERYPARAMSREQUEST._serialized_start = 429
    _QUERYPARAMSREQUEST._serialized_end = 449
    _QUERYPROVIDERSRESPONSE._serialized_start = 452
    _QUERYPROVIDERSRESPONSE._serialized_end = 594
    _QUERYPROVIDERRESPONSE._serialized_start = 596
    _QUERYPROVIDERRESPONSE._serialized_end = 675
    _QUERYPARAMSRESPONSE._serialized_start = 677
    _QUERYPARAMSRESPONSE._serialized_end = 750
    _QUERYSERVICE._serialized_start = 753
    _QUERYSERVICE._serialized_end = 1188
